@@ -1,6 +1,7 @@
+
 import astropy.units as u
 from astropy.coordinates import Galactic, SkyCoord, SpectralCoord
-from astropy.wcs.wcsapi.sliced_low_level_wcs import SlicedLowLevelWCS
+from astropy.wcs.wcsapi.wrappers import SlicedLowLevelWCS
 from numpy.testing import assert_allclose, assert_equal
 
 EXPECTED_ELLIPSIS_REPR = """
